<?php
/**
 * The Lake beneath the Opera functions and definitions
 *
 * @package The Lake beneath the Opera
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
 global $content_width;
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}
function the_lake_beneath_the_opera_adjust_content_width() {
    global $content_width;
 
    if ( is_page_template( 'template-full-width-page.php' ) )
        $content_width = 780;
}
add_action( 'template_redirect', 'the_lake_beneath_the_opera_adjust_content_width' );

if ( ! function_exists( 'the_lake_beneath_the_opera_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function the_lake_beneath_the_opera_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on The Lake beneath the Opera, use a find and replace
	 * to change 'the_lake_beneath_the_opera' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'the_lake_beneath_the_opera', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'the_lake_beneath_the_opera' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'the_lake_beneath_the_opera_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
		'caption',
	) );
add_theme_support( "post-thumbnails" );
add_theme_support( "title-tag" );
add_editor_style();
}
endif; // the_lake_beneath_the_opera_setup
add_action( 'after_setup_theme', 'the_lake_beneath_the_opera_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function the_lake_beneath_the_opera_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'the_lake_beneath_the_opera' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	register_sidebar( array(
        'name' => __( 'Secondary Widget Area', 'the_lake_beneath_the_opera' ),
        'id' => 'sidebar-2',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ) );
}
add_action( 'widgets_init', 'the_lake_beneath_the_opera_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function the_lake_beneath_the_opera_scripts() {
	
	wp_enqueue_style( 'the_lake_beneath_the_opera-style', get_stylesheet_uri() . '' );

	wp_enqueue_script( 'the_lake_beneath_the_opera-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	
	wp_enqueue_script( 'the_lake_beneath_the_opera_scripts', get_template_directory_uri() . '/js/respond.js', array(), '20130115', true );
	
	wp_enqueue_script( 'the_lake_beneath_the_opera_scripts', get_template_directory_uri() . '/js/html5shiv.js', array(), true );

	wp_enqueue_script( 'the_lake_beneath_the_opera-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'the_lake_beneath_the_opera_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
//require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
//require get_template_directory() . '/inc/jetpack.php';



/* Enqueue Playball Google font */
function the_lake_beneath_the_opera_fonts() {
    $protocol = is_ssl() ? 'https' : 'http';
    wp_enqueue_style( 'the_lake_beneath_the_opera-playball', "$protocol://fonts.googleapis.com/css?family=Playball" );}
add_action( 'wp_enqueue_scripts', 'the_lake_beneath_the_opera_fonts' );
